..
    Copyright 2021 IRT Saint Exupéry, https://www.irt-saintexupery.com

    This work is licensed under the Creative Commons Attribution-ShareAlike 4.0
    International License. To view a copy of this license, visit
    http://creativecommons.org/licenses/by-sa/4.0/ or send a letter to Creative
    Commons, PO Box 1866, Mountain View, CA 94042, USA.

A GUI to create input and output files template for DiscFromExe.

Documentation
-------------

See www.gemseo.org.

License
-------

`GEMSEO <http://gemseo.org/>`_
    GNU LGPL v3.0

Contributors
------------

- GEMSEO team
